@@ -1124,6 +1124,9 @@ def plot_streamline_metrics(trk, tList: list, metric_maps: list,
     if groundTruth_map is not None:
         axs.plot(vList, mgtList, label='Ground truth')
     axs.legend()
+    axs.set_ylabel('Metric')
+    axs.set_xlabel('Streamline segment position')
+    axs.set_title('Microstructure along streamline')
 
 
 def plot_streamline_metrics_old(streamList: list, metric_maps: list,
@@ -1387,10 +1390,7 @@ def total_segment_length(fixel_weights):
 
     '''
 
-    if len(fixel_weights.shape) <= 3:
-        return fixel_weights
-
-    sc = np.sum(fixel_weights, axis=3)
+    sc = np.sum(fixel_weights, axis=len(fixel_weights.shape)-1)
 
     return sc
 
@@ -1417,7 +1417,7 @@ def get_microstructure_map(fixelWeights, metricMapList: list):
     total_weight = np.sum(fixelWeights, axis=len(fixelWeights.shape)-1)
 
     for k, metricMap in enumerate(metricMapList):
-        slic = tuple([slice(None)]*(len(fixelWeights.shape))-1)+(k,)
+        slic = tuple([slice(None)]*(len(fixelWeights.shape)-1))+(k,)
         microMap += metricMap*fixelWeights[slic]
 
     microMap[total_weight != 0] /= total_weight[total_weight != 0]
@@ -1458,10 +1458,16 @@ def get_weighted_mean(microstructure_map, fixel_weights,
     else:
         weighted_map = tsl
 
+    if np.sum(weighted_map) == 0:
+        return 0, 0
+
     mean = np.sum(microstructure_map*weighted_map)/np.sum(weighted_map)
 
     M = np.count_nonzero(weighted_map)
 
+    if M == 1:
+        return mean, 0
+
     dev = np.sqrt(np.sum(weighted_map*np.square(microstructure_map-mean)) /
                   ((M-1)/M*np.sum(weighted_map)))
 
